% Script sp2_demo1.m
% Script to demonstrate use of NeuroSpec1.0 spectral analysis and plotting routines.
%
% Copyright 2002, David M. Halliday.
% This file is part of NeuroSpec.
%
%    NeuroSpec is free software; you can redistribute it and/or modify
%    it under the terms of the GNU General Public License as published by
%    the Free Software Foundation; either version 2 of the License, or
%    (at your option) any later version.
%
%    NeuroSpec is distributed in the hope that it will be useful,
%    but WITHOUT ANY WARRANTY; without even the implied warranty of
%    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
%    GNU General Public License for more details.
%
%    You should have received a copy of the GNU General Public License
%    along with NeuroSpec; if not, write to the Free Software
%    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
%
%    NeuroSpec is available at:  http://www.neurospec.org/
%    Contact:  contact@neurospec.org
%

%--------------------------------------------------------------------------
% Section 1: Usage of sp2a2_m.m

% Generate some data: Two channels with 10^5 points.
% Normally distributed, zero mean, unit variance: N(0,1).
dat=randn(100000,2);
% Add third column which is average of first two.
dat(:,3)=0.5*(dat(:,1)+dat(:,2));

% For purposes of analysis: assume sampling rate is 1000/sec
samp_rate=1000;

% Set power for segment length as 10.
% Thus T=2^10 = 1024.
seg_pwr=10;

% Process columns 1 and 2, these are Uncorrelated
[f,t,cl]=sp2a2_m(dat(:,1),dat(:,2),1000,10);
cl.what='N(0,1) uncorrelated data';
figure
% The sampling rate defines the nyquist frequency as 500 Hz.
psp2(f,t,cl,500,500,250,.5)

% Process columns 1 and 3, these are Correlated (column 1 contributed to column 3)
[f1,t1,cl1]=sp2a2_m(dat(:,1),dat(:,3),1000,10);
cl1.what='Correlated data';
figure
psp2(f1,t1,cl1,500,50,25,1)

% Column 4 is delayed version of column3. Delay of 10 samples.
dat(1:10,4)=randn(10,1);         % First 10 samples generated independently
dat(11:100000,4)=dat(1:99990,3); % Subsequent samples in column 4 copied from column 3.

% Process columns 2 and 4, these are Correlated & Delayed
%  Column 2 contributed to column 3, column 4 is delayed version of column 3.
[f2,t2,cl2]=sp2a2_m(dat(:,2),dat(:,4),1000,10);
cl2.what='Correlated & delayed data 1';
figure
psp2(f2,t2,cl2,500,50,25,1)

% Generated filtered version of column 1.
% Filtering done using 11 point moving average window.
a=1;
b=(ones(1,11)/11)';
dat_filt=filter(b,a,dat(:,1));

% Column 5 is average of filtered version of column 1 and column 2.
dat(:,5)=0.5*(dat_filt+dat(:,2));


% Process columns 1 and 5, these are Correlated & Filtered
[f3,t3,cl3]=sp2a2_m(dat(:,1),dat(:,5),1000,10);
cl3.what='Correlated & filtered data 1';
figure
psp2(f3,t3,cl3,100,50,25,1)

%--------------------------------------------------------------------------
% Section 2: Usage of sp2_m.m 

% Generate some spike train data.
% Clear these each time.
clear int1 int2 sp sp1 sp2

% First spike train, Mean Interval=100 sampling bins, STD=10 sampling bins.
% Generate 1200 inter spike intervals.
int1=round(randn(1200,1)*10+100);
% Sum these to get spike/event times.
for ind=1:length(int1)
  sp(ind,1)=sum(int1(1:ind));
end
% Now copy to sp1 those spike times less than 100000
% This represents 100 seconds @ 1 ms sampling, same as time series data.
sp1(1:length(find(sp<100000)),1)=sp(1:length(find(sp<100000)));

% Second spike train, Mean Interval=100 sampling bins, STD=20 sampling bins.
% Generate 1200 inter spike intervals.
int2=round(randn(1200,1)*20+100);
% Sum these to get spike/event times.
for ind=1:length(int2)
  sp(ind,1)=sum(int2(1:ind));
end 
% Now copy to sp2 those spike times less than 100000
% This represents 100 seconds @ 1 ms sampling, same as time series data.
sp2(1:length(find(sp<100000)),1)=sp(1:length(find(sp<100000)));

% Now now have two independent spike trains both with a mean rate of 10 spikes/sec,
% the first with an STD of 10 sampling bins, the second with an STD of 20 sampling bins.

% Process these using sp2_m
[f4,t4,cl4]=sp2_m(sp1,sp2,1000,10);
cl4.what='Independent Spike Trains';
figure
psp2(f4,t4,cl4,75,100,50,.5)

%--------------------------------------------------------------------------
% Section 3: Usage of sp2a_m.m

% Now have spike train (point process) and time series data.Do hybrid analysis using
%  spike train data from section 2 and time series data from section1.

[f5,t5,cl5]=sp2a_m(sp1,dat(:,1),1000,10);
cl5.what='Hybrid analysis';
figure
psp2(f5,t5,cl5,75,100,50,.5)
